@@ -4,11 +4,11 @@ Author: Marc Billow
 License: MIT
 """
 from .api import RedPocket  # noqa: F401
-from .exceptions import (
+from .exceptions import (  # noqa: F401
     RedPocketException,
     RedPocketAuthError,
     RedPocketAPIError,
-)  # noqa: F401
+)
 
 
-__version__ = "0.1.0"
+__version__ = "0.1.2"
